dm: treewide: Rename ..._platdata variables to just ..._plat

Try to maintain some consistency between these variables by using _plat as
a suffix for them.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/include/dm/platform_data/fsl_espi.h b/include/dm/platform_data/fsl_espi.h
index 812933f..de2307f 100644
--- a/include/dm/platform_data/fsl_espi.h
+++ b/include/dm/platform_data/fsl_espi.h
@@ -6,7 +6,7 @@
 #ifndef __fsl_espi_h
 #define __fsl_espi_h
 
-struct fsl_espi_platdata {
+struct fsl_espi_plat {
 	uint flags;
 	uint speed_hz;
 	uint num_chipselect;
diff --git a/include/dm/platform_data/pxa_mmc_gen.h b/include/dm/platform_data/pxa_mmc_gen.h
index 9875bab..d15c155 100644
--- a/include/dm/platform_data/pxa_mmc_gen.h
+++ b/include/dm/platform_data/pxa_mmc_gen.h
@@ -9,7 +9,7 @@
 #include <mmc.h>
 
 /*
- * struct pxa_mmc_platdata - information about a PXA MMC controller
+ * struct pxa_mmc_plat - information about a PXA MMC controller
  *
  * @base:	MMC controller base register address
  */
diff --git a/include/dm/platform_data/serial_bcm283x_mu.h b/include/dm/platform_data/serial_bcm283x_mu.h
index 37f5174..6c77272 100644
--- a/include/dm/platform_data/serial_bcm283x_mu.h
+++ b/include/dm/platform_data/serial_bcm283x_mu.h
@@ -14,7 +14,7 @@
  *
  * @base: Register base address
  */
-struct bcm283x_mu_serial_platdata {
+struct bcm283x_mu_serial_plat {
 	unsigned long base;
 	unsigned int clock;
 	bool skip_init;
diff --git a/include/dm/platform_data/serial_mxc.h b/include/dm/platform_data/serial_mxc.h
index 86cd3bc..cc59eeb 100644
--- a/include/dm/platform_data/serial_mxc.h
+++ b/include/dm/platform_data/serial_mxc.h
@@ -7,7 +7,7 @@
 #define __serial_mxc_h
 
 /* Information about a serial port */
-struct mxc_serial_platdata {
+struct mxc_serial_plat {
 	struct mxc_uart *reg;  /* address of registers in physical memory */
 	bool use_dte;
 };
diff --git a/include/dm/platform_data/serial_pl01x.h b/include/dm/platform_data/serial_pl01x.h
index 77d96c4..e3d4e30 100644
--- a/include/dm/platform_data/serial_pl01x.h
+++ b/include/dm/platform_data/serial_pl01x.h
@@ -20,7 +20,7 @@
  * @skip_init: Don't attempt to change port configuration (also means @clock
  * is ignored)
  */
-struct pl01x_serial_platdata {
+struct pl01x_serial_plat {
 	unsigned long base;
 	enum pl01x_type type;
 	unsigned int clock;
diff --git a/include/dm/platform_data/serial_sh.h b/include/dm/platform_data/serial_sh.h
index 711435d..69cd012 100644
--- a/include/dm/platform_data/serial_sh.h
+++ b/include/dm/platform_data/serial_sh.h
@@ -27,7 +27,7 @@
  * @clk_mode:	Clock mode, set internal (INT) or external (EXT)
  * @type:	Type of SCIF
  */
-struct sh_serial_platdata {
+struct sh_serial_plat {
 	unsigned long base;
 	unsigned int clk;
 	enum sh_clk_mode clk_mode;
diff --git a/include/dm/platform_data/spi_davinci.h b/include/dm/platform_data/spi_davinci.h
index fbc62c2..42a467e 100644
--- a/include/dm/platform_data/spi_davinci.h
+++ b/include/dm/platform_data/spi_davinci.h
@@ -7,7 +7,7 @@
 #ifndef __spi_davinci_h
 #define __spi_davinci_h
 
-struct davinci_spi_platdata {
+struct davinci_spi_plat {
 	struct davinci_spi_regs *regs;
 	u8 num_cs;	   /* total no. of CS available */
 };
diff --git a/include/dm/platform_data/lpc32xx_hsuart.h b/include/dm/platform_data/lpc32xx_hsuart.h
index 9bfd628..6f41e0e73 100644
--- a/include/dm/platform_data/lpc32xx_hsuart.h
+++ b/include/dm/platform_data/lpc32xx_hsuart.h
@@ -7,11 +7,11 @@
 #define _LPC32XX_HSUART_PLAT_H
 
 /**
  * struct lpc32xx_hsuart_platdata - NXP LPC32xx HSUART platform data
  *
  * @base:               Base register address
  */
-struct lpc32xx_hsuart_platdata {
+struct lpc32xx_hsuart_plat {
 	unsigned long base;
 };
 
@@ -7,11 +7,11 @@
 
 /**
- * struct lpc32xx_hsuart_platdata - NXP LPC32xx HSUART platform data
+ * struct lpc32xx_hsuart_plat - NXP LPC32xx HSUART platform data
  *
  * @base:               Base register address
diff --git a/include/dm/platform_data/serial_coldfire.h b/include/dm/platform_data/serial_coldfire.h
index ba916fe..5e265e9 100644
--- a/include/dm/platform_data/serial_coldfire.h
+++ b/include/dm/platform_data/serial_coldfire.h
@@ -7,13 +7,13 @@
 #define __serial_coldfire_h
 
 /*
  * struct coldfire_serial_platdata - information about a coldfire port
  *
  * @base:               Uart port base register address
  * @port:               Uart port index, for cpu with pinmux for uart / gpio
  * baudrtatre:          Uart port baudrate
  */
-struct coldfire_serial_platdata {
+struct coldfire_serial_plat {
 	unsigned long base;
 	int port;
 	int baudrate;
@@ -7,13 +7,13 @@
 
 /*
- * struct coldfire_serial_platdata - information about a coldfire port
+ * struct coldfire_serial_plat - information about a coldfire port
  *
  * @base:               Uart port base register address
diff --git a/include/dm/platform_data/serial_pxa.h b/include/dm/platform_data/serial_pxa.h
index b78bdb6..0d7dc4c 100644
--- a/include/dm/platform_data/serial_pxa.h
+++ b/include/dm/platform_data/serial_pxa.h
@@ -40,13 +40,13 @@
 #endif
 
 /*
  * struct pxa_serial_platdata - information about a PXA port
  *
  * @base:	Uart port base register address
  * @port:	Uart port index, for cpu with pinmux for uart / gpio
  * baudrtatre:	Uart port baudrate
  */
-struct pxa_serial_platdata {
+struct pxa_serial_plat {
 	struct pxa_uart_regs *base;
 	int port;
 	int baudrate;
@@ -40,13 +40,13 @@
 
 /*
- * struct pxa_serial_platdata - information about a PXA port
+ * struct pxa_serial_plat - information about a PXA port
  *
  * @base:	Uart port base register address
diff --git a/include/dm/platform_data/spi_coldfire.h b/include/dm/platform_data/spi_coldfire.h
index 8ad8eae..da514ba 100644
--- a/include/dm/platform_data/spi_coldfire.h
+++ b/include/dm/platform_data/spi_coldfire.h
@@ -10,14 +10,14 @@
 #define MAX_CTAR_FIELDS		8
 
 /*
  * struct coldfire_spi_platdata - information about a coldfire spi module
  *
  * @regs_addr: base address for module registers
  * @speed_hz: default SCK frequency
  * @mode: default SPI mode
  * @num_cs: number of DSPI chipselect signals
  */
-struct coldfire_spi_platdata {
+struct coldfire_spi_plat {
 	fdt_addr_t regs_addr;
 	uint speed_hz;
 	uint mode;
@@ -10,14 +10,14 @@
 
 /*
- * struct coldfire_spi_platdata - information about a coldfire spi module
+ * struct coldfire_spi_plat - information about a coldfire spi module
  *
  * @regs_addr: base address for module registers
diff --git a/include/dm/root.h b/include/dm/root.h
index 113e92e..89afbee 100644
--- a/include/dm/root.h
+++ b/include/dm/root.h
@@ -31,7 +31,7 @@
 void dm_fixup_for_gd_move(struct global_data *new_gd);
 
 /**
  * dm_scan_platdata() - Scan all platform data and bind drivers
  *
  * This scans all available plat and creates drivers for each
  *
@@ -39,7 +39,7 @@
  * flag. If false bind all drivers.
  * @return 0 if OK, -ve on error
  */
-int dm_scan_platdata(bool pre_reloc_only);
+int dm_scan_plat(bool pre_reloc_only);
 
 /**
  * dm_scan_fdt() - Scan the device tree and bind drivers
@@ -31,7 +31,7 @@
 
 /**
- * dm_scan_platdata() - Scan all platform data and bind drivers
+ * dm_scan_plat() - Scan all platform data and bind drivers
  *
  * This scans all available plat and creates drivers for each